@@ -60,7 +60,7 @@ setClass(Class = 'BooleanTable', contains = 'matrix', validity = function(object
 #' Function [BooleanTable] returns a \linkS4class{BooleanTable} object.
 #' 
 #' @seealso 
-#' End-user may also use \link[caret]{confusionMatrix}, 
+#' End-user may also use function `caret::confusionMatrix`, 
 #' which does not provide confidence intervals of 
 #' sensitivity, specificity, etc.
 #' 
@@ -182,7 +182,6 @@ npv <- function(prevalence, sensitivity, specificity) {
 #' summary(BooleanTable(x))
 #' summary(BooleanTable(x), prevalence = c(.0001, .001, .01))
 #' 
-#' @importFrom e1071 classAgreement
 #' @importFrom stats binom.test pnorm qnorm
 #' @keywords internal
 #' @export summary.BooleanTable
@@ -255,6 +254,7 @@ summary.BooleanTable <- function(object, prevalence, ...) {
     fmt = 'Diagnose Accuracy: %.1f%% (=(%d+%d)/%d, 95%% CI %.1f%%~%.1f%%)\n',
     1e2 * (x11+x00)/sum(x), x11, x00, sum(x)), as.list.default(1e2 * binom.test(x = x11+x00, n = sum(x))$conf.int))))
   
+  # @importFrom e1071 classAgreement
   #kp <- classAgreement(x)$kappa
   #cat(sprintf(fmt = 'Cohen\'s Inter-Rater Agreement \u03ba = %.3f (%s)\n', kp, as.character.factor(cut_kappa(kp))))
   # need to @include cut_kappa.R
@@ -266,77 +266,3 @@ summary.BooleanTable <- function(object, prevalence, ...) {
 }
 
 
-
-#' @title Plot of Predictive Values of Boolean Test-&-Disease Table
-#' 
-#' @description 
-#' Plot of predictive values of Boolean test-&-disease table
-#' 
-#' @param object a \linkS4class{BooleanTable} object
-#' 
-#' @param prevalence (optional) \link[base]{numeric} scalar, prevalence of disease
-#' 
-#' @param ... potential parameters, currently not in use 
-#' 
-#' @returns 
-#' Function [autoplot.BooleanTable] returns a \link[ggplot2]{ggplot} figure,
-#' which shows the curves of positive and negative predictive values for prevalence from 0 to 1.
-#' 
-#' @examples 
-#' (x = array(c(95L, 10L, 31L, 82L), dim = c(2L, 2L)))
-#' library(ggplot2)
-#' autoplot(BooleanTable(x))
-#' autoplot(BooleanTable(x), prevalence = .13)
-#' 
-#' @importFrom ggplot2 autolayer geom_function geom_point aes scale_colour_discrete labs xlim
-#' @importFrom ggrepel geom_label_repel 
-#' @importFrom utils capture.output
-#' @seealso [summary.BooleanTable]
-#' @keywords internal
-#' @name autoplot.BooleanTable
-#' @export autolayer.BooleanTable
-#' @export
-autolayer.BooleanTable <- function(object, prevalence, ...) {
-  
-  capture.output(tmp <- summary.BooleanTable(object))
-  sens <- tmp$sens
-  spec <- tmp$spec
-  
-  lyr_curve <- list(
-    geom_function(mapping = aes(colour = 'ppv'), fun = ppv, args = list(sensitivity = sens, specificity = spec)),
-    geom_function(mapping = aes(colour = 'npv'), fun = npv, args = list(sensitivity = sens, specificity = spec)),
-    #xlim(0, 1),
-    scale_colour_discrete(name = 'Predictive\nValues', breaks = c('ppv', 'npv'), labels = c('Positive PV', 'Negative PV')),
-    labs(x = 'Prevalence', y = 'Predictive Value', 
-         caption = sprintf(fmt = 'Sensitivity = %.1f%%; Specificity = %.1f%%', 1e2*sens, 1e2*spec))
-  )
-    
-  
-  lyr_point <- if (!missing(prevalence)) {
-    if (!is.double(prevalence) || !length(prevalence) || anyNA(prevalence) ||
-        any(prevalence < 0, prevalence > 1)) stop('`prevalence` must be between 0 and 1 (inclusive)')
-    ppv_ <- ppv(prevalence, sensitivity = sens, specificity = spec)
-    npv_ <- npv(prevalence, sensitivity = sens, specificity = spec)
-    list(
-      geom_point(mapping = aes(x = prevalence, y = ppv_, colour = 'ppv'), size = 2L),
-      geom_label_repel(mapping = aes(x = prevalence, y = ppv_, colour = 'ppv', label = sprintf(fmt = '%.1f%%', 1e2*ppv_)), size = 3.5),
-      geom_point(mapping = aes(x = prevalence, y = npv_, colour = 'npv'), size = 2L),
-      geom_label_repel(mapping = aes(x = prevalence, y = npv_, colour = 'npv', label = sprintf(fmt = '%.1f%%', 1e2*npv_)), size = 3.5)
-    )
-  } # else NULL
-  
-  return(c(lyr_curve, lyr_point))
-  
-}
-
-
-#' @importFrom ggplot2 autoplot ggplot scale_y_continuous scale_x_continuous
-#' @importFrom scales percent
-#' @rdname autoplot.BooleanTable
-#' @export autoplot.BooleanTable
-#' @export
-autoplot.BooleanTable <- function(object, ...) {
-  ggplot() + autolayer.BooleanTable(object, ...) +
-    scale_y_continuous(labels = percent) + 
-    scale_x_continuous(labels = percent, limits = c(0, 1))
-}
